==> haskell-happstack-server-7.8.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-happstack-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 happstack-server
version:              7.8.0
visibility:           public
id:                   happstack-server-7.8.0-8d7dv6lAFIBCHXMyMSIFqM
key:                  happstack-server-7.8.0-8d7dv6lAFIBCHXMyMSIFqM
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  cb7472698546f5e04ab61596255b1176
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.0.2/site-local/happstack-server-7.8.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/happstack-server-7.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.8.0-8d7dv6lAFIBCHXMyMSIFqM
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-FOp1Agqy33pIuogSynRJiT
    blaze-html-0.9.1.2-Faw7GcDP8ACI1arIncgCAJ bytestring-0.10.12.1
    containers-0.6.4.1 directory-1.3.6.2 exceptions-0.10.4
    extensible-exceptions-0.1.1.4-FO4Sw13oBkvBW8j4vnJTpA
    filepath-1.4.2.1 hslogger-1.3.1.0-ApLcqnxUkD22iUc3aBGaZe
    html-1.0.1.2-BYpT6zvcyak8RR9ba7PA72
    monad-control-1.0.3.1-DlsUqLFbWM58bb5zwVUuLI mtl-2.2.2
    network-3.1.2.7-3dAlKyu2TU91rkKNmDqxd9
    network-uri-2.6.4.1-DpIvCtUeaVVBZXUmMpeWC3
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh parsec-3.1.14.0
    process-1.6.13.2 sendfile-0.7.11.4-8ZxolGeX3mU97oQqAHjYZk
    syb-0.7.2.1-AxFN4KGxWlA3uSocGRGhiw
    system-filepath-0.4.14-ACsxIWQLtHo4zIIiUnxJ70 text-1.2.5.0
    threads-0.5.1.6-HoRMxkm7LvzA65XBBpqZbX time-1.9.3
    transformers-0.5.6.2 transformers-base-0.4.6-AvztNa1j503JqrdvzzYBKC
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH unix-2.7.2.2
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f xhtml-3000.2.2.1
    zlib-0.6.3.0-FBHK82ssrfHNsPX1KyzFW

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-happstack-server-7.8.0.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-happstack-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 happstack-server
version:              7.8.0.1
visibility:           public
id:                   happstack-server-7.8.0.1-FldK3PJtk7mC0Z6n1jtC6E
key:                  happstack-server-7.8.0.1-FldK3PJtk7mC0Z6n1jtC6E
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  e5155729a033f40b8ed06640393fe0d9
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.0.2/site-local/happstack-server-7.8.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/happstack-server-7.8.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.8.0.1-FldK3PJtk7mC0Z6n1jtC6E
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-4eiDBc5nMqA1X3Go5ETdH3
    blaze-html-0.9.1.2-6Aj0HufOHd6EjVRytlZiR6 bytestring-0.10.12.1
    containers-0.6.4.1 directory-1.3.6.2 exceptions-0.10.4
    extensible-exceptions-0.1.1.4-FO4Sw13oBkvBW8j4vnJTpA
    filepath-1.4.2.1 hslogger-1.3.1.0-3piz6scM647DVCqzt8ZJCN
    html-1.0.1.2-BYpT6zvcyak8RR9ba7PA72
    monad-control-1.0.3.1-IrzDamBWLivVDST3y06Lb mtl-2.2.2
    network-3.1.2.7-BgmWCPLmmVsKjis2BFXpFm
    network-uri-2.6.4.1-DK574ArzyuHIMsQqcen8XH
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh parsec-3.1.14.0
    process-1.6.13.2 sendfile-0.7.11.4-3KAJFTPi7tYAsEQI7E3ck
    syb-0.7.2.2-8yUDZDN1zlNKFBJiDzETDr
    system-filepath-0.4.14-FaW1tQCZSkHAlCKn9QYI4j text-1.2.5.0
    threads-0.5.1.7-7P00BrB2rWo3JqSswIerec time-1.9.3
    transformers-0.5.6.2 transformers-base-0.4.6-CpidT3TUuuG7oKu8iZs8cR
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH unix-2.7.2.2
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f xhtml-3000.2.2.1
    zlib-0.6.3.0-ASkwAfTzdD6IlY6OtD1xLy

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
